/*************************************************************************************
#
#	Main.h
#	
#	An extremely basic encoder utility to assist in building all of the various
#   "compiled" resources used by MoofWars.  Many of the encoder utilities are actually
#   handled by things in the standard TGraphic class, so the main reason for pre-encoding
#   the graphics is to improve the time to load the graphics in the game.
#   
#
#	Author: Timothy Carroll
#	Apple Developer Technical Support
#	timc@apple.com
#
#	Modification History: 
#
#	8/15/96		TMC 	Initial Release
#
#	Copyright  1996 Apple Computer, Inc., All Rights Reserved
#
#
#	You may incorporate this sample code into your applications without
#	restriction, though the sample code has been provided "AS IS" and the
#	responsibility for its operation is 100% yours.  However, what you are
#	not permitted to do is to redistribute the source as "DSC Sample Code"
#	after having made changes. If you're going to re-distribute the source,
#	we require that you make it clear in the source that the code was
#	descended from Apple Sample Code, but that you've made changes.
#
*************************************************************************************/

#ifndef _MOOFENCODE_
#define _MOOFENCODE_

#pragma once

#include <MacHeadersPPC++>
#include <Quickdraw.h>
#include <QDOffscreen.h>
#include <Palettes.h>
#include <DrawSprocket.h>


/*************************************************************************************
#
#	CONDITIONALS
#
#   Like MoofWars, we'll define a few conditional macros that assist in configuring how
#   the application actually works.  For the moment, we'll just have one, the debugging macro.
#
#
#	qDebugging  -- Whether or not additional debugging code should be inserted.  With this
#   turned on, most errors will DebugStr almost immediately and return errors as the error
#   propagates up the calling chain.  This is slower, but if you've found a weird bug,
#   this is the fastest way to replicate it.
#
*************************************************************************************/

#define qDebugging 1


/*********************************************************************************
#	ERROR HANDLING MACROS
#
#	These macros can be used to implement nice error handling within a function.
#	Essentially, all errors jump to an error handler at the end of the function, which
#	should cleanup  any leftovers and return the appropriate error result.
#
#	Note that the error handlers take a message string.  This should be a good
#	indication of the actual error, and it will appear when debugging is turned on.
#
#	Note that any additional sanity checking code can be added to any function by using
#
	
	#if qDebugging
  		// do additional sanity checking here.
	#endif
#
#	For example, this could be used to check the internal validity of an object before
#	taking an action.
#	
*********************************************************************************/
#ifndef qDebugging
	#define qDebugging 0
#endif

#if qDebugging
	#define SIGNAL_ERROR(msg)		{DebugStr(msg); goto error;}
#else
	#define SIGNAL_ERROR(msg)		{goto error;}
#endif

#define FAIL_NIL(y,msg)			if (y == NULL) SIGNAL_ERROR(msg)
#define FAIL_OSERR(y,msg)		if (y != noErr) SIGNAL_ERROR(msg)
#define FAIL_FALSE(y,msg)		if (!y) SIGNAL_ERROR(msg)
	

/*********************************************************************************
	OTHER NECESSARY HEADERS	
*********************************************************************************/
#include "Scaling.h"
#include "TGraphicCollection.h"


/*********************************************************************************
	CONSTANTS	
*********************************************************************************/


// A few standard colors -- probably should use palette calls instead!
const RGBColor kWhite = {0xFFFF, 0xFFFF, 0xFFFF};
const RGBColor kBlack = {0x0000, 0x0000, 0x0000};
const RGBColor kDarkBlue = {0x0000,0x0000,0x7000};
const RGBColor kLtGrey = {0xC000,0xC000,0xC000};
const RGBColor kMediumGrey = {0x7FFF,0x7FFF,0x7FFF};

// The ResID of the application's color table.  All of my custom graphics routines use
// an 8-bit color table and the sprite is encoded to use these colors.  The actual variable
// to hold the color table is declared below.

enum {
	kAppColorTableResID = 128
};

// Various constants used to load the background tile and sprite graphics.

enum {
	kGridResourceID = 500
};

enum {
	kPreferredDepth = 8
};

// We'll use these contants to tailor the Application's behavior.
enum {
	kEventInterval = 3,
	kNumberOfMasters = 10,
	kSleepTime = 0
};

// Constants for all the menu functions
enum
{
	rMenuBar = 128,
	mAppleMenu = 128,
		iAboutApp = 1,
	mFileMenu = 129,
		iEncodeIcons = 1,
		iEncodePICTs = 2,
		iTriplePICTs = 4,
		iEncodeTiles = 5,
		iQuit = 7
};

/*********************************************************************************
	Globals	
*********************************************************************************/

// The main color table described above
extern CTabHandle			gAppColorTable;


/*********************************************************************************
	Functions	
*********************************************************************************/

OSStatus CopyResource (SInt16 inRes, SInt16 outRes, OSType theType, SInt16 theID);

#endif /* _MOOFENCODE_ */

